usage
-----

.. code:: sh

   pip install cjutils

.. code:: python3

   python3 -m cjutils -h
   python3 -m cjutils --example
   # write an example plugin into ./cmds/example_ext.py

   python -m cjutils example -h
